;========================================================
;       INCLUDE FILE
;       CONTAINS MEMORY REGISTERS
;       68HC11 SERIES MICROCONTROLLER
;========================================================
$BASE 10T
;************************************
;BYTE DESIGNATIONS
;************************************
PORTA   EQU     $00   ; I/O PORT A
;               $01   ; RESERVED
PIOC    EQU     $02   ; PARALLEL I/O CONTROL REGISTER
PORTC   EQU     $03   ; I/O PORT C
PORTB   EQU     $04   ; I/O PORT B
PORTCL  EQU     $05   ; ALTERNATE LATCHED PORT C
DDRB    EQU     $06   ; DATA DIRECTION FOR PORT B              (D3 SERIES ONLY)
DDRC    EQU     $07   ; DATA DIRECTION FOR PORT C
PORTD   EQU     $08   ; I/O PORT D
DDRD    EQU     $09   ; DATA DIRECTION FOR PORT D
PORTE   EQU     $0A   ; INPUT PORT E                           (NOT IN D3 SERIES)
CFORC   EQU     $0B   ; COMPARE FORCE REGISTER
OC1M    EQU     $0C   ; OC1 ACTION MASK REGISTER
OC1D    EQU     $0D   ; OC1 ACTION DATA REGISTER
TCNT    EQU     $0E   ; TIMER COUNTER REGISTER         HIGH
;       EQU     $0F   ;                                LOW
TIC1    EQU     $10   ; INPUT CAPTURE 1 REGISTER       HIGH
;       EQU     $11   ;                                LOW
TIC2    EQU     $12   ; INPUT CAPTURE 2 REGISTER       HIGH
;       EQU     $13   ;                                LOW
TIC3    EQU     $14   ; INPUT CAPTURE 3 REGISTER       HIGH
;       EQU     $15   ;                                LOW
TOC1    EQU     $16   ; OUTPUT COMPARE 1 REGISTER      HIGH
;       EQU     $17   ;                                LOW
TOC2    EQU     $18   ; OUTPUT COMPARE 2 REGISTER      HIGH
;       EQU     $19   ;                                LOW
TOC3    EQU     $1A   ; OUTPUT COMPARE 3 REGISTER      HIGH
;       EQU     $1B   ;                                LOW
TOC4    EQU     $1C   ; OUTPUT COMPARE 4 REGISTER      HIGH
;       EQU     $1D   ;                                LOW
TI4O5   EQU     $1E   ; OUTPUT COMPARE 5 REGISTER      HIGH    (NOT IN D3)
;       EQU     $1F   ; INPUT CAPTURE 4 REGISTER       LOW     (NOT IN D3,A8)
TCTL1   EQU     $20   ; TIMER CONTROL REGISTER 1               (NOT IN D3)
TCTL2   EQU     $21   ; TIMER CONTROL REGISTER 1               (NOT IN D3)
TMSK1   EQU     $22   ; TIMER INTERRUPT MASK REG. 1            (NOT IN D3)
TFLG1   EQU     $23   ; TIMER INTERRUPT FLAG REG. 1
TMSK2   EQU     $24   ; TIMER INTERRUPT MASK REG. 2
TFLG2   EQU     $25   ; TIMER INTERRUPT FLAG REG. 2
PACTL   EQU     $26   ; PULSE ACCUM. CONTROL REG.
PACNT   EQU     $27   ; PULSE ACCUM. COUNT REG.
SPCR    EQU     $28   ; SPI CONTROL REGISTER
SPSR    EQU     $29   ; SPI FLAG REGISTER
SPDR    EQU     $2A   ; SPI DATA REGISTER
BAUD    EQU     $2B   ; SCI BAUD RATE CONTROL
SCCR1   EQU     $2C   ; SCI CONTROL REGISTER 1
SCCR2   EQU     $2D   ; SCI CONTROL REGISTER 2
SCSR    EQU     $2E   ; SCI STATUS REGISTER
SCDR    EQU     $2F   ; SCI DATA (READ RDR,WRITE TDR)
ADR1    EQU     $30   ; A/D CONTROL REGISTER 1                 (NOT IN D3)
ADR2    EQU     $31   ; A/D CONTROL REGISTER 2                 (NOT IN D3)
ADR3    EQU     $32   ; A/D CONTROL REGISTER 3                 (NOT IN D3)
ADR4    EQU     $33   ; A/D CONTROL REGISTER 4                 (NOT IN D3)
BPROT   EQU     $34   ; EEPROM BLOCK PROTECT REG.              (NOT IN D3 OR A8)
;       EQU     $35   ; RESERVED
;       EQU     $36   ; RESERVED
;       EQU     $37   ; RESERVED
;       EQU     $38   ; RESERVED
OPTION  EQU     $39   ; SYSTEM CONFIGURATION OPTIONS
COPRST  EQU     $3A   ; ARM/RESET COP TIMER CIRCUIT
PPROG   EQU     $3B   ; NOT IN D3
HIPRIO  EQU     $3C   ; EEPROM PROGRAM CONTROL REG.
INIT    EQU     $3D   ; HIGHEST PRIORITY I-BIT INT AND MISC.
TEST1   EQU     $3E   ; FACTORY TEST CONTROL REGISTER
CONFIG  EQU     $3F   ; COP,ROM,AND EEPROM ENABLES

;************************************
;BIT  DESIGNATIONS
;************************************
PA0     EQU     1       ;PORT A
PA1     EQU     2
PA2     EQU     4
PA3     EQU     8
PA4     EQU     16
PA5     EQU     32
PA6     EQU     64
PA7     EQU     128
PB0     EQU     1       ;PORT B
PB1     EQU     2
PB2     EQU     4
PB3     EQU     8
PB4     EQU     16
PB5     EQU     32
PB6     EQU     64
PB7     EQU     128
PC0     EQU     1       ;PORT C
PC1     EQU     2
PC2     EQU     4
PC3     EQU     8
PC4     EQU     16
PC5     EQU     32
PC6     EQU     64
PC7     EQU     128
PD0     EQU     1       ;PORT D
PD1     EQU     2
PD2     EQU     4
PD3     EQU     8
PD4     EQU     16
PD5     EQU     32
PD6     EQU     64
PD7     EQU     128
PE0     EQU     1       ;PORT E
PE1     EQU     2
PE2     EQU     4
PE3     EQU     8
PE4     EQU     16
PE5     EQU     32
PE6     EQU     64
PE7     EQU     128
DDA3    EQU     8       ;PACTL
DDA7    EQU     128
DDB0    EQU     1       ;DDRB
DDB1    EQU     2
DDB2    EQU     4
DDB3    EQU     8
DDB4    EQU     16
DDB5    EQU     32
DDB6    EQU     64
DDB7    EQU     128
DDC0    EQU     1       ;DDRC
DDC1    EQU     2
DDC2    EQU     4
DDC3    EQU     8
DDC4    EQU     16
DDC5    EQU     32
DDC6    EQU     64
DDC7    EQU     128
DDD0    EQU     1       ;DDRD
DDD1    EQU     2
DDD2    EQU     4
DDD3    EQU     8
DDD4    EQU     16
DDD5    EQU     32
DDD6    EQU     64
DDD7    EQU     128
CWOM    EQU     32      ;PIOC
FOC1    EQU     128     ;CFORC
FOC2    EQU     64
FOC3    EQU     32
FOC4    EQU     16
FOC5    EQU     8
OC1M7   EQU     128     ;OC1M
OC1M6   EQU     64
OC1M5   EQU     32
OC1M4   EQU     16
OC1M3   EQU     8
OC1D7   EQU     128     ;OC1D
OC1D6   EQU     64
OC1D5   EQU     32
OC1D4   EQU     16
OC1D3   EQU     8
OC1F    EQU     128     ;TFLG1
OC2F    EQU     64
OC3F    EQU     32
OC4F    EQU     16
OC5F    EQU     8
IC4F    EQU     8
IC1F    EQU     4
IC2F    EQU     2
IC3F    EQU     1
TOI     EQU     128     ;TMSK2
RTII    EQU     64
PAOVI   EQU     32
PAII    EQU     16
PR1     EQU     2
PR0     EQU     1
TOF     EQU     128     ;TFLG2
RTIF    EQU     64
PAOVF   EQU     32
PAIF    EQU     16
PAEN    EQU     64     ;PACTL
PAMOD   EQU     32
PEDGE   EQU     16
OC5     EQU     4
IC4     EQU     4
RTR1    EQU     2
RTR0    EQU     1
SPIE    EQU     128     ;SPCR
SPE     EQU     64
DWOM    EQU     32
MSTR    EQU     16
CPOL    EQU     8
CPHA    EQU     4
SPR1    EQU     2
SPR0    EQU     1
SPIF    EQU     128     ;SPSR
WCOL    EQU     64
MODF    EQU     16
TCLR    EQU     128     ;BAUD
SCP1    EQU     32
SCP0    EQU     16
RCKB    EQU     8
SCR2    EQU     4
SCR1    EQU     2
SCR0    EQU     1
R8      EQU     128     ;SCCR1
T8      EQU     64
M       EQU     16
WAKE    EQU     8
TIE     EQU     128     ;SCCR2
TCIE    EQU     64
RIE     EQU     32
ILIE    EQU     16
TE      EQU     8
RE      EQU     4
RWU     EQU     2
SBK     EQU     1
TDRE    EQU     128     ;SCSR
TC      EQU     64
RDRF    EQU     32
IDLE    EQU     16
OR      EQU     8
NF      EQU     4
FE      EQU     2
CCF     EQU     128     ;ADCTL
SCAN    EQU     32
MULT    EQU     16
CD      EQU     8
CC      EQU     4
CB      EQU     2
CA      EQU     1
ADPU    EQU     128     ;OPTION
CSEL    EQU     64
IRQE    EQU     32
DLY     EQU     16
CME     EQU     8
CR1     EQU     2
CR0     EQU     1
ODD     EQU     128     ;PPROG
EVEN    EQU     64
BYTE    EQU     16
ROW     EQU     8
ERASE   EQU     4
EELAT   EQU     2
EEPGM   EQU     1
RBOOT   EQU     128     ;HPRIO
SMOD    EQU     64
MDA     EQU     32
IRV     EQU     16
PSEL3   EQU     8
PSEL2   EQU     4
PSEL1   EQU     2
PSEL0   EQU     1
RAM3    EQU     128     ;INIT
RAM2    EQU     64
RAM1    EQU     32
RAM0    EQU     16
REG3    EQU     8
REG2    EQU     4
REG1    EQU     2
REG0    EQU     1
TILOP   EQU     128     ;TEST1
OCCR    EQU     32
CBYP    EQU     16
DISR    EQU     8
FCM     EQU     4
FCOP    EQU     2
TCON    EQU     1
NOSEC   EQU     8       ;CONFIG
NOCOP   EQU     4
ROMON   EQU     2
EEON    EQU     1
EDG4B   EQU     128     ;TCTL2
EDG4A   EQU     64
EDG1B   EQU     32
EDG1A   EQU     16
EDG2B   EQU     8
EDG2A   EQU     4
EDG3B   EQU     2
EDG3A   EQU     1
OM2     EQU     128     ;TCTL1
OL2     EQU     64
OM3     EQU     32
OL3     EQU     16
OM4     EQU     8
OL4     EQU     4
OM5     EQU     2
OL5     EQU     1
OC1I    EQU     128
OC2I    EQU     64
OC3I    EQU     32
OC4I    EQU     16
OC5I    EQU     8
IC1I    EQU     4
IC2I    EQU     2
IC3I    EQU     1
IC4I    EQU     8
